@@ -75,10 +75,16 @@ def run(filename, in_filename, safe):
     default="*.cpp",
     help="Name of C++ file to compile and run",
 )
-def comp(filename):
+@click.option(
+    "--safe/--fast",
+    "safe",
+    default=True,
+    help="Controls whether compiler is run with a number of safety checks",
+)
+def comp(filename, safe):
     """Compiles a C++ program"""
     try:
-        _compile(filename)
+        _compile(filename, safe)
     except RuntimeError:
         click.echo(click.style("Something went wrong in compilation", fg="red"))
         return
@@ -98,7 +104,6 @@ def _compile(filename, safe=True):
             "-Wlogical-op",
             "-fsanitize=address",
             "-fsanitize=undefined",
-            "-fno-sanitize-recover",
             "-fstack-protector",
         ]
     compiler = subprocess.run(command, check=False)
